==> james-project-3.6.2-source-release.zip: james-project/mailbox/elasticsearch-v7/src/main/java/org/apache/james/mailbox/elasticsearch/v7/json/EMailer.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox.elasticsearch.v7.json;

import java.util.Objects;
import java.util.Optional;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.Joiner;
import com.google.common.base.MoreObjects;

public class EMailer implements SerializableMessage {

    private final Optional<String> name;
    private final String address;

    public EMailer(Optional<String> name, String address) {
        this.name = name;
        this.address = address;
    }

    @JsonProperty(JsonMessageConstants.EMailer.NAME)
    public Optional<String> getName() {
        return name;
    }

    @JsonProperty(JsonMessageConstants.EMailer.ADDRESS)
    public String getAddress() {
        return address;
    }

    @Override
    public String serialize() {
        return Joiner.on(" ").join(name, address);
    }

    @Override
    public final boolean equals(Object o) {
        if (o instanceof EMailer) {
            EMailer otherEMailer = (EMailer) o;
            return Objects.equals(name, otherEMailer.name)
                && Objects.equals(address, otherEMailer.address);
        }
        return false;
    }

    @Override
    public final int hashCode() {
        return Objects.hash(name, address);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
            .add("name", name)
            .add("address", address)
            .toString();
    }
}

==> james-project-3.7.6-source-release.zip: james-project/mailbox/elasticsearch-v7/src/main/java/org/apache/james/mailbox/elasticsearch/v7/json/EMailer.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox.elasticsearch.v7.json;

import java.util.Objects;
import java.util.Optional;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.Joiner;
import com.google.common.base.MoreObjects;

public class EMailer implements SerializableMessage {

    private final Optional<String> name;
    private final String address;

    public EMailer(Optional<String> name, String address) {
        this.name = name;
        this.address = address;
    }

    @JsonProperty(JsonMessageConstants.EMailer.NAME)
    public Optional<String> getName() {
        return name;
    }

    @JsonProperty(JsonMessageConstants.EMailer.ADDRESS)
    public String getAddress() {
        return address;
    }

    @Override
    public String serialize() {
        return Joiner.on(" ").join(name.orElse(" "), address);
    }

    @Override
    public final boolean equals(Object o) {
        if (o instanceof EMailer) {
            EMailer otherEMailer = (EMailer) o;
            return Objects.equals(name, otherEMailer.name)
                && Objects.equals(address, otherEMailer.address);
        }
        return false;
    }

    @Override
    public final int hashCode() {
        return Objects.hash(name, address);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
            .add("name", name)
            .add("address", address)
            .toString();
    }
}
